@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: murmur-hash
-version: 0.1
-id: murmur-hash-0.1-ff138a67ef9b7e95b33b44cf47cebebb
+version: 0.1.0.2
+id: murmur-hash-0.1.0.2-84236d963ec095b8dd8b79cb14107413
 
 license: BSD3
 copyright:
@@ -21,19 +21,19 @@ pkgpath: devel/hs-murmur-hash
 exposed: True
 exposed-modules: Data.Digest.Murmur32 Data.Digest.Murmur64
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/murmur-hash-0.1
-library-dirs: /usr/local/lib/ghc/murmur-hash-0.1
-hs-libraries: HSmurmur-hash-0.1
+import-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.2
+library-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.2
+hs-libraries: HSmurmur-hash-0.1.0.2
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.2.0.2-578c91f7479ca9d00c13da2ed514f7ac
+depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-murmur-hash-0.1/html/murmur-hash.haddock
-haddock-html: /usr/local/share/doc/hs-murmur-hash-0.1/html
+haddock-interfaces: /usr/local/share/doc/hs-murmur-hash-0.1.0.2/html/murmur-hash.haddock
+haddock-html: /usr/local/share/doc/hs-murmur-hash-0.1.0.2/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
